.. _tso_photometry_step:

=======================
TSO Aperture Photometry
=======================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.tso_photometry
